@@ -1,7 +1,7 @@
+#!/usr/bin/env python
 # -*- coding:utf-8 -*-
-# /usr/bin/env python
 """
-Date: 2021/7/1 16:07
+Date: 2021/10/22 14:07
 Desc: COVID-19
 COVID-19-网易
 COVID-19-丁香园
@@ -11,7 +11,7 @@ COVID-19-GitHub
 import json
 import time
 
-import demjson
+from mssdk.utils import demjson
 import jsonpath
 import pandas as pd
 import requests
@@ -22,7 +22,7 @@ from mssdk.event.cons import province_dict, city_dict
 
 def covid_19_163(indicator: str = "实时") -> pd.DataFrame:
     """
-    网易-新冠状病毒
+    网易-新型冠状病毒
     https://news.163.com/special/epidemic/?spssid=93326430940df93a37229666dfbc4b96&spsw=4&spss=other&#map_block
     https://news.163.com/special/epidemic/?spssid=93326430940df93a37229666dfbc4b96&spsw=4&spss=other&
     :return: 返回指定 indicator 的数据
@@ -206,6 +206,7 @@ def covid_19_163(indicator: str = "实时") -> pd.DataFrame:
 def covid_19_dxy(indicator: str = "浙江省") -> pd.DataFrame:
     """
     20200315-丁香园接口更新分为国内和国外
+    https://ncov.dxy.cn/ncovh5/view/pneumonia
     丁香园-全国统计-info
     丁香园-分地区统计-data
     丁香园-全国发热门诊一览表-hospital
@@ -215,14 +216,14 @@ def covid_19_dxy(indicator: str = "浙江省") -> pd.DataFrame:
     :return: 返回指定 indicator 的数据
     :rtype: pandas.DataFrame
     """
-    url = "https://3g.dxy.cn/newh5/view/pneumonia"
+    url = "https://ncov.dxy.cn/ncovh5/view/pneumonia"
     r = requests.get(url)
     r.encoding = "utf-8"
     soup = BeautifulSoup(r.text, "lxml")
     # news-china
     text_data_news = str(soup.find("script", attrs={"id": "getTimelineService1"}))
     temp_json = text_data_news[
-        text_data_news.find("= [{") + 2: text_data_news.rfind("}catch")
+        text_data_news.find("= [{") + 2 : text_data_news.rfind("}catch")
     ]
     json_data = pd.DataFrame(json.loads(temp_json))
     chinese_news = json_data[
@@ -265,7 +266,7 @@ def covid_19_dxy(indicator: str = "浙江省") -> pd.DataFrame:
     # info
     dxy_static = str(soup.find("script", attrs={"id": "getStatisticsService"}))
     data_json = json.loads(
-        dxy_static[dxy_static.find("= {") + 2: dxy_static.rfind("}c")]
+        dxy_static[dxy_static.find("= {") + 2 : dxy_static.rfind("}c")]
     )
     china_statistics = pd.DataFrame(
         [
@@ -334,11 +335,56 @@ def covid_19_dxy(indicator: str = "浙江省") -> pd.DataFrame:
             if sub_area.empty:
                 return None
             if sub_area.shape[1] != 10:
-                sub_area.columns = ["区域", "现在确诊人数", "确诊人数", "疑似人数", "治愈人数", "死亡人数", "高危人数", "中危人数", "id", "_", "_"]
-                sub_area = sub_area[["区域", "现在确诊人数", "确诊人数", "疑似人数", "治愈人数", "死亡人数", "高危人数", "中危人数", ]]
+                sub_area.columns = [
+                    "区域",
+                    "现在确诊人数",
+                    "确诊人数",
+                    "疑似人数",
+                    "治愈人数",
+                    "死亡人数",
+                    "高危人数",
+                    "中危人数",
+                    "id",
+                    "_",
+                    "_",
+                ]
+                sub_area = sub_area[
+                    [
+                        "区域",
+                        "现在确诊人数",
+                        "确诊人数",
+                        "疑似人数",
+                        "治愈人数",
+                        "死亡人数",
+                        "高危人数",
+                        "中危人数",
+                    ]
+                ]
             else:
-                sub_area.columns = ["区域", "现在确诊人数", "确诊人数", "疑似人数", "治愈人数", "死亡人数", "高危人数", "中危人数", "id", "_"]
-                sub_area = sub_area[["区域", "现在确诊人数", "确诊人数", "疑似人数", "治愈人数", "死亡人数", "高危人数", "中危人数", ]]
+                sub_area.columns = [
+                    "区域",
+                    "现在确诊人数",
+                    "确诊人数",
+                    "疑似人数",
+                    "治愈人数",
+                    "死亡人数",
+                    "高危人数",
+                    "中危人数",
+                    "id",
+                    "_",
+                ]
+                sub_area = sub_area[
+                    [
+                        "区域",
+                        "现在确诊人数",
+                        "确诊人数",
+                        "疑似人数",
+                        "治愈人数",
+                        "死亡人数",
+                        "高危人数",
+                        "中危人数",
+                    ]
+                ]
             return sub_area
         except IndexError:
             print("请输入省/市的全称, 如: 浙江省/上海市 等")
@@ -363,7 +409,6 @@ def covid_19_baidu(indicator: str = "浙江") -> pd.DataFrame:
     data_json = demjson.decode(
         temp_soup[temp_soup.find("{") : temp_soup.rfind("}") + 1]
     )
-
     big_df = pd.DataFrame()
     for i, p in enumerate(
         jsonpath.jsonpath(data_json["component"][0]["caseList"], "$..area")
@@ -411,6 +456,119 @@ def covid_19_baidu(indicator: str = "浙江") -> pd.DataFrame:
         ["area", "died", "crued", "confirmed", "confirmedRelative"]
     ]
 
+    url = "https://opendata.baidu.com/data/inner"
+    params = {
+        "tn": "reserved_all_res_tn",
+        "dspName": "iphone",
+        "from_sf": "1",
+        "dsp": "iphone",
+        "resource_id": "28565",
+        "alr": "1",
+        "query": "国内新型肺炎最新动态",
+    }
+    r = requests.get(url, params=params)
+    data_json = r.json()
+    temp_df = pd.DataFrame(
+        data_json["Result"][0]["items_v2"][0]["aladdin_res"]["DisplayData"]["result"][
+            "items"
+        ]
+    )
+    temp_df.rename(
+        {
+            "bjh_na": "_",
+            "eventDescription": "新闻",
+            "eventTime": "时间",
+            "eventUrl": "链接",
+            "homepageUrl": "_",
+            "item_avatar": "_",
+            "siteName": "来源",
+        },
+        axis=1,
+        inplace=True,
+    )
+    temp_df.set_index(pd.to_datetime(temp_df["时间"], unit="s", utc=True), inplace=True)
+    temp_df.index = (
+        pd.to_datetime(temp_df["时间"], unit="s", utc=True)
+        .tz_convert("Asia/Shanghai")
+        .index
+    )
+    del temp_df["时间"]
+    temp_df.reset_index(inplace=True)
+    temp_df["时间"] = (
+        pd.to_datetime(temp_df["时间"])
+        .dt.date.astype(str)
+        .str.cat(pd.to_datetime(temp_df["时间"]).dt.time.astype(str), sep=" ")
+    )
+    temp_df = temp_df[
+        [
+            "新闻",
+            "时间",
+            "来源",
+            "链接",
+        ]
+    ]
+    domestic_news = temp_df
+
+    params = {
+        "tn": "reserved_all_res_tn",
+        "dspName": "iphone",
+        "from_sf": "1",
+        "dsp": "iphone",
+        "resource_id": "28565",
+        "alr": "1",
+        "query": "国外新型肺炎最新动态",
+    }
+    r = requests.get(url, params=params)
+    data_json = r.json()
+    temp_df = pd.DataFrame(
+        data_json["Result"][0]["items_v2"][0]["aladdin_res"]["DisplayData"]["result"][
+            "items"
+        ]
+    )
+    temp_df.rename(
+        {
+            "bjh_na": "_",
+            "eventDescription": "新闻",
+            "eventTime": "时间",
+            "eventUrl": "链接",
+            "homepageUrl": "_",
+            "item_avatar": "_",
+            "siteName": "来源",
+        },
+        axis=1,
+        inplace=True,
+    )
+    temp_df = temp_df[
+        [
+            "新闻",
+            "时间",
+            "来源",
+            "链接",
+        ]
+    ]
+    temp_df.set_index(pd.to_datetime(temp_df["时间"], unit="s", utc=True), inplace=True)
+    temp_df.index = (
+        pd.to_datetime(temp_df["时间"], unit="s", utc=True)
+        .tz_convert("Asia/Shanghai")
+        .index
+    )
+    del temp_df["时间"]
+    temp_df.reset_index(inplace=True)
+    temp_df["时间"] = (
+        pd.to_datetime(temp_df["时间"])
+        .dt.date.astype(str)
+        .str.cat(pd.to_datetime(temp_df["时间"]).dt.time.astype(str), sep=" ")
+    )
+    temp_df = temp_df[
+        [
+            "新闻",
+            "时间",
+            "来源",
+            "链接",
+        ]
+    ]
+    foreign_news = temp_df
+
     if indicator == "中国分省份详情":
         return domestic_province_df
     elif indicator == "中国分城市详情":
@@ -423,6 +581,10 @@ def covid_19_baidu(indicator: str = "浙江") -> pd.DataFrame:
         return global_continent_df
     elif indicator == "全球分洲国家详情":
         return global_country_df
+    elif indicator == "国内新型肺炎最新动态":
+        return domestic_news
+    elif indicator == "国外新型肺炎最新动态":
+        return foreign_news
 
 
 def migration_area_baidu(
@@ -458,7 +620,7 @@ def migration_area_baidu(
         "date": date,
     }
     r = requests.get(url, params=params)
-    data_text = r.text[r.text.find("({") + 1: r.text.rfind(");")]
+    data_text = r.text[r.text.find("({") + 1 : r.text.rfind(");")]
     data_json = json.loads(data_text)
     temp_df = pd.DataFrame(data_json["data"]["list"])
     return temp_df
@@ -536,42 +698,53 @@ def covid_19_trace() -> pd.DataFrame:
     }
     r = requests.get(url, headers=headers)
     data_json = r.json()
-    province_list = [item['fullname'] for item in data_json['result']['list']]
+    province_list = [item["fullname"] for item in data_json["result"]["list"]]
     big_df = pd.DataFrame()
     for province in province_list:
         url = "https://apis.map.qq.com/place_cloud/search/region"
         params = {
-            'region': province,
-            'page_size': '200',
-            'table_id': '5ff7d526b34a3525c3169a0b',
-            'key': 'NFPBZ-D2N3P-T7FDV-VLBQ6-4DVM7-JQFCR',
-            'fliter': '',
+            "region": province,
+            "page_size": "200",
+            "table_id": "5ff7d526b34a3525c3169a0b",
+            "key": "NFPBZ-D2N3P-T7FDV-VLBQ6-4DVM7-JQFCR",
+            "fliter": "",
         }
         headers = {
             "Referer": "https://news.qq.com/",
             "Host": "apis.map.qq.com",
             "Origin": "https://news.qq.com",
-            "user-agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1"
+            "user-agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1",
         }
         r = requests.get(url, params=params, headers=headers)
         data_json = r.json()
-        risk_level = [item['x']['risk_level'] for item in data_json['result']['data']]
-        count_time = [item['x']['datetime'] for item in data_json['result']['data']]
-        temp_df = pd.DataFrame(data_json['result']['data'])
-        del temp_df['location']
-        del temp_df['id']
-        del temp_df['polygon']
-        del temp_df['tel']
-        del temp_df['ud_id']
-        del temp_df['adcode']
-        del temp_df['x']
-        temp_df['update_time'] = pd.to_datetime(temp_df['update_time'], unit='s')
-        temp_df['create_time'] = pd.to_datetime(temp_df['create_time'], unit='s')
-        temp_df['risk_level'] = risk_level
-        temp_df['count_time'] = count_time
-        del temp_df['create_time']
+        risk_level = [item["x"]["risk_level"] for item in data_json["result"]["data"]]
+        count_time = [item["x"]["datetime"] for item in data_json["result"]["data"]]
+        temp_df = pd.DataFrame(data_json["result"]["data"])
+        del temp_df["location"]
+        del temp_df["id"]
+        del temp_df["polygon"]
+        del temp_df["tel"]
+        del temp_df["ud_id"]
+        del temp_df["adcode"]
+        del temp_df["x"]
+        temp_df["update_time"] = pd.to_datetime(temp_df["update_time"], unit="s")
+        temp_df["create_time"] = pd.to_datetime(temp_df["create_time"], unit="s")
+        temp_df["risk_level"] = risk_level
+        temp_df["count_time"] = count_time
+        del temp_df["create_time"]
         big_df = big_df.append(temp_df, ignore_index=True)
     big_df.columns = [
+        "地址",
+        "城市",
+        "区",
+        "_",
+        "省份",
+        "标题",
+        "更新时间",
+        "风险等级",
+        "统计时间",
+    ]
+    big_df = big_df[[
         "地址",
         "城市",
         "区",
@@ -580,7 +753,7 @@ def covid_19_trace() -> pd.DataFrame:
         "更新时间",
         "风险等级",
         "统计时间",
-    ]
+    ]]
     return big_df
 
 
@@ -616,20 +789,6 @@ def covid_19_hist_province(province: str = "湖北省") -> pd.DataFrame:
     return data_df[data_df["province"] == province]
 
 
-def covid_19_history() -> pd.DataFrame:
-    """
-    接口最好用代理速度比较快, 2019-12-01 开始 2020-12-08
-    https://github.com/canghailan/Wuhan-2019-nCoV
-    :return: 疫情数据
-    :rtype: pandas.DataFrame
-    """
-    url = "https://raw.githubusercontent.com/canghailan/Wuhan-2019-nCoV/master/Wuhan-2019-nCoV.json"
-    r = requests.get(url)
-    data_json = r.json()
-    data_df = pd.DataFrame(data_json)
-    return data_df
-
-
 def covid_19_csse_daily(date: str = "2020-04-06") -> pd.DataFrame:
     """
     2019 Novel Coronavirus COVID-19 (2019-nCoV) Data Repository by Johns Hopkins CSSE, 采集 GitHub csv 文件需要 raw 地址
@@ -756,6 +915,8 @@ if __name__ == "__main__":
         "国外分城市详情",
         "全球分洲详情",
         "全球分洲国家详情",
+        "国内新型肺炎最新动态",
+        "国外新型肺炎最新动态",
     ]
     for item in indicator_list:
         print(item)
@@ -784,13 +945,10 @@ if __name__ == "__main__":
     # 历史数据
     epidemic_hist_city_df = covid_19_hist_city(city="武汉市")
     print(epidemic_hist_city_df)
+
     epidemic_hist_province_df = covid_19_hist_province(province="湖北省")
     print(epidemic_hist_province_df)
 
-    # 详细历史数据
-    epidemic_history_df = covid_19_history()
-    print(epidemic_history_df)
-
     # CSSE
     covid_19_csse_daily_df = covid_19_csse_daily(date="2020-04-13")
     print(covid_19_csse_daily_df)
