@@ -1,7 +1,7 @@
+#!/usr/bin/env python
 # -*- coding:utf-8 -*-
-# /usr/bin/env python
 """
-Date: 2021/1/21 9:48
+Date: 2021/11/20 18:18
 Desc: 东方财富网站-天天基金网-基金数据-开放式基金净值
 http://fund.eastmoney.com/manager/default.html#dt14;mcreturnjson;ftall;pn20;pi1;scabbname;stasc
 1.基金经理基本数据, 建议包含:基金经理代码,基金经理姓名,从业起始日期,现任基金公司,管理资产总规模,上述数据可在"基金经理列表: http://fund.eastmoney.com/manager/default.html#dt14;mcreturnjson;ftall;pn20;pi1;scabbname;stasc 和"基金经理理档案如:http://fund.eastmoney.com/manager/30040164.html 获取.
@@ -10,9 +10,8 @@ http://fund.eastmoney.com/manager/default.html#dt14;mcreturnjson;ftall;pn20;pi1;
 用户ID:269993
 """
 import time
-import json
 
-import demjson
+from mssdk.utils import demjson
 import pandas as pd
 import requests
 
@@ -38,7 +37,7 @@ def fund_em_fund_name() -> pd.DataFrame:
 
 def fund_em_open_fund_daily() -> pd.DataFrame:
     """
-    东方财富网站-天天基金网-基金数据-开放式基金净值
+    东方财富网-天天基金网-基金数据-开放式基金净值
     http://fund.eastmoney.com/fund.html#os_0;isall_0;ft_;pt_1
     :return: 当前交易日的所有开放式基金净值数据
     :rtype: pandas.DataFrame
@@ -106,10 +105,10 @@ def fund_em_open_fund_daily() -> pd.DataFrame:
 
 
 def fund_em_open_fund_info(
-    fund: str = "710001", indicator: str = "单位净值走势"
+    fund: str = "580007", indicator: str = "单位净值走势"
 ) -> pd.DataFrame:
     """
-    东方财富网站-天天基金网-基金数据-开放式基金净值
+    东方财富网-天天基金网-基金数据-开放式基金净值
     http://fund.eastmoney.com/fund.html#os_0;isall_0;ft_;pt_1
     :param fund: 基金代码; 可以通过调用 fund_em_open_fund_daily 获取所有开放式基金代码
     :type fund: str
@@ -123,15 +122,15 @@ def fund_em_open_fund_info(
     headers = {
         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.149 Safari/537.36"
     }
-    res = requests.get(url, headers=headers)
-    text = res.text
+    r = requests.get(url, headers=headers)
+    data_text = r.text
 
     # 单位净值走势
     if indicator == "单位净值走势":
         data_json = demjson.decode(
-            text[
-                text.find("Data_netWorthTrend")
-                + 21 : text.find("Data_ACWorthTrend")
+            data_text[
+                data_text.find("Data_netWorthTrend")
+                + 21 : data_text.find("Data_ACWorthTrend")
                 - 15
             ]
         )
@@ -153,13 +152,16 @@ def fund_em_open_fund_info(
                 "日增长率",
             ]
         ]
+        temp_df['净值日期'] = pd.to_datetime(temp_df['净值日期']).dt.date
+        temp_df['单位净值'] = pd.to_numeric(temp_df['单位净值'])
+        temp_df['日增长率'] = pd.to_numeric(temp_df['日增长率'])
         return temp_df
 
     # 累计净值走势
     if indicator == "累计净值走势":
         data_json = demjson.decode(
-            text[
-                text.find("Data_ACWorthTrend") + 20: text.find("Data_grandTotal") - 16
+            data_text[
+                data_text.find("Data_ACWorthTrend") + 20 : data_text.find("Data_grandTotal") - 16
             ]
         )
         temp_df = pd.DataFrame(data_json)
@@ -178,14 +180,16 @@ def fund_em_open_fund_info(
                 "累计净值",
             ]
         ]
+        temp_df['净值日期'] = pd.to_datetime(temp_df['净值日期']).dt.date
+        temp_df['累计净值'] = pd.to_numeric(temp_df['累计净值'])
         return temp_df
 
     # 累计收益率走势
     if indicator == "累计收益率走势":
         data_json = demjson.decode(
-            text[
-                text.find("Data_grandTotal")
-                + 18 : text.find("Data_rateInSimilarType")
+            data_text[
+                data_text.find("Data_grandTotal")
+                + 18 : data_text.find("Data_rateInSimilarType")
                 - 15
             ]
         )
@@ -207,14 +211,16 @@ def fund_em_open_fund_info(
                 "累计收益率",
             ]
         ]
+        temp_df_main['净值日期'] = pd.to_datetime(temp_df_main['净值日期']).dt.date
+        temp_df_main['累计收益率'] = pd.to_numeric(temp_df_main['累计收益率'])
         return temp_df_main
 
     # 同类排名走势
     if indicator == "同类排名走势":
         data_json = demjson.decode(
-            text[
-                text.find("Data_rateInSimilarType")
-                + 25: text.find("Data_rateInSimilarPersent")
+            data_text[
+                data_text.find("Data_rateInSimilarType")
+                + 25 : data_text.find("Data_rateInSimilarPersent")
                 - 16
             ]
         )
@@ -235,14 +241,17 @@ def fund_em_open_fund_info(
                 "总排名-每日近三月排名",
             ]
         ]
+        temp_df['报告日期'] = pd.to_datetime(temp_df['报告日期']).dt.date
+        temp_df['同类型排名-每日近三月排名'] = pd.to_numeric(temp_df['同类型排名-每日近三月排名'])
+        temp_df['总排名-每日近三月排名'] = pd.to_numeric(temp_df['总排名-每日近三月排名'])
         return temp_df
 
     # 同类排名百分比
     if indicator == "同类排名百分比":
         data_json = demjson.decode(
-            text[
-                text.find("Data_rateInSimilarPersent")
-                + 26 : text.find("Data_fluctuationScale")
+            data_text[
+                data_text.find("Data_rateInSimilarPersent")
+                + 26 : data_text.find("Data_fluctuationScale")
                 - 23
             ]
         )
@@ -262,24 +271,34 @@ def fund_em_open_fund_info(
                 "同类型排名-每日近3月收益排名百分比",
             ]
         ]
+        temp_df['报告日期'] = pd.to_datetime(temp_df['报告日期']).dt.date
+        temp_df['同类型排名-每日近3月收益排名百分比'] = pd.to_numeric(temp_df['同类型排名-每日近3月收益排名百分比'])
         return temp_df
 
     # 分红送配详情
     if indicator == "分红送配详情":
         url = f"http://fundf10.eastmoney.com/fhsp_{fund}.html"
         r = requests.get(url, headers=headers)
-        return pd.read_html(r.text)[1]
+        temp_df = pd.read_html(r.text)[1]
+        if temp_df.iloc[0, 1] == '暂无分红信息!':
+            return None
+        else:
+            return temp_df
 
     # 拆分详情
     if indicator == "拆分详情":
         url = f"http://fundf10.eastmoney.com/fhsp_{fund}.html"
         r = requests.get(url, headers=headers)
-        return pd.read_html(r.text)[2]
+        temp_df = pd.read_html(r.text)[2]
+        if temp_df.iloc[0, 1] == '暂无拆分信息!':
+            return None
+        else:
+            return temp_df
 
 
 def fund_em_money_fund_daily() -> pd.DataFrame:
     """
-    东方财富网站-天天基金网-基金数据-货币型基金收益
+    东方财富网-天天基金网-基金数据-货币型基金收益
     http://fund.eastmoney.com/HBJJ_pjsyl.html
     :return: 当前交易日的所有货币型基金收益数据
     :rtype: pandas.DataFrame
@@ -316,7 +335,7 @@ def fund_em_money_fund_daily() -> pd.DataFrame:
 
 def fund_em_money_fund_info(fund: str = "000009") -> pd.DataFrame:
     """
-    东方财富网站-天天基金网-基金数据-货币型基金收益-历史净值数据
+    东方财富网-天天基金网-基金数据-货币型基金收益-历史净值数据
     http://fundf10.eastmoney.com/jjjz_004186.html
     :param fund: 货币型基金代码, 可以通过 fund_em_money_fund_daily 来获取
     :type fund: str
@@ -595,7 +614,7 @@ def fund_em_graded_fund_info(fund: str = "150232") -> pd.DataFrame:
 
 def fund_em_etf_fund_daily() -> pd.DataFrame:
     """
-    东方财富网站-天天基金网-基金数据-场内交易基金
+    东方财富网-天天基金网-基金数据-场内交易基金
     http://fund.eastmoney.com/cnjy_dwjz.html
     :return: 当前交易日的所有场内交易基金数据
     :rtype: pandas.DataFrame
@@ -629,12 +648,18 @@ def fund_em_etf_fund_daily() -> pd.DataFrame:
     return temp_df
 
 
-def fund_em_etf_fund_info(fund: str = "511280") -> pd.DataFrame:
+def fund_em_etf_fund_info(
+    fund: str = "511280", start_date: str = "20000101", end_date: str = "20500101"
+) -> pd.DataFrame:
     """
     东方财富网站-天天基金网-基金数据-场内交易基金-历史净值明细
     http://fundf10.eastmoney.com/jjjz_511280.html
     :param fund: 场内交易基金代码, 可以通过 fund_em_etf_fund_daily 来获取
     :type fund: str
+    :param start_date: 开始统计时间
+    :type start_date: str
+    :param end_date: 结束统计时间
+    :type end_date: str
     :return: 东方财富网站-天天基金网-基金数据-场内交易基金-历史净值明细
     :rtype: pandas.DataFrame
     """
@@ -648,8 +673,8 @@ def fund_em_etf_fund_info(fund: str = "511280") -> pd.DataFrame:
         "fundCode": fund,
         "pageIndex": "1",
         "pageSize": "10000",
-        "startDate": "",
-        "endDate": "",
+        "startDate": "-".join([start_date[:4], start_date[4:6], start_date[6:]]),
+        "endDate": "-".join([end_date[:4], end_date[4:6], end_date[6:]]),
         "_": round(time.time() * 1000),
     }
     r = requests.get(url, params=params, headers=headers)
@@ -672,6 +697,10 @@ def fund_em_etf_fund_info(fund: str = "511280") -> pd.DataFrame:
         "_",
     ]
     temp_df = temp_df[["净值日期", "单位净值", "累计净值", "日增长率", "申购状态", "赎回状态"]]
+    temp_df["净值日期"] = pd.to_datetime(temp_df["净值日期"]).dt.date
+    temp_df["单位净值"] = pd.to_numeric(temp_df["单位净值"])
+    temp_df["累计净值"] = pd.to_numeric(temp_df["累计净值"])
+    temp_df["日增长率"] = pd.to_numeric(temp_df["日增长率"])
     return temp_df
 
 
@@ -759,14 +788,16 @@ def fund_em_value_estimation(symbol: str = "全部") -> pd.DataFrame:
         ]
     ]
     temp_df.reset_index(inplace=True)
-    temp_df["index"] = range(1, len(temp_df)+1)
+    temp_df["index"] = range(1, len(temp_df) + 1)
     temp_df.rename(columns={"index": "序号"}, inplace=True)
     return temp_df
 
 
-def fund_em_hk_fund_hist(code: str = '1002200683', symbol: str = "历史净值明细") -> pd.DataFrame:
+def fund_em_hk_fund_hist(
+    code: str = "1002200683", symbol: str = "历史净值明细"
+) -> pd.DataFrame:
     """
-    东方财富网站-天天基金网-基金数据-香港基金-历史净值明细(分红送配详情)
+    东方财富网-天天基金网-基金数据-香港基金-历史净值明细(分红送配详情)
     http://overseas.1234567.com.cn/f10/FundJz/968092#FHPS
     :param code: 通过 fund_em_hk_rank 获取
     :type code: str
@@ -781,19 +812,19 @@ def fund_em_hk_fund_hist(code: str = '1002200683', symbol: str = "历史净值
     }
     if symbol == "历史净值明细":
         params = {
-            'api': 'HKFDApi',
-            'm': 'MethodJZ',
-            'hkfcode': f'{code}',
-            'action': '2',
-            'pageindex': '0',
-            'pagesize': '1000',
-            'date1': '',
-            'date2': '',
-            '_': '1611131371333',
+            "api": "HKFDApi",
+            "m": "MethodJZ",
+            "hkfcode": f"{code}",
+            "action": "2",
+            "pageindex": "0",
+            "pagesize": "1000",
+            "date1": "",
+            "date2": "",
+            "_": "1611131371333",
         }
         r = requests.get(url, params=params, headers=headers)
         data_json = r.json()
-        temp_one_df = pd.DataFrame(data_json['Data'])
+        temp_one_df = pd.DataFrame(data_json["Data"])
         temp_one_df.columns = [
             "_",
             "_",
@@ -817,19 +848,19 @@ def fund_em_hk_fund_hist(code: str = '1002200683', symbol: str = "历史净值
         ]
     else:
         params = {
-            'api': 'HKFDApi',
-            'm': 'MethodJZ',
-            'hkfcode': f'{code}',
-            'action': '3',
-            'pageindex': '0',
-            'pagesize': '1000',
-            'date1': '',
-            'date2': '',
-            '_': '1611131371333',
+            "api": "HKFDApi",
+            "m": "MethodJZ",
+            "hkfcode": f"{code}",
+            "action": "3",
+            "pageindex": "0",
+            "pagesize": "1000",
+            "date1": "",
+            "date2": "",
+            "_": "1611131371333",
         }
         r = requests.get(url, params=params, headers=headers)
         data_json = r.json()
-        temp_one_df = pd.DataFrame(data_json['Data'])
+        temp_one_df = pd.DataFrame(data_json["Data"])
         temp_one_df.columns = [
             "_",
             "_",
@@ -861,31 +892,41 @@ def fund_em_hk_fund_hist(code: str = '1002200683', symbol: str = "历史净值
 if __name__ == "__main__":
     fund_em_fund_name_df = fund_em_fund_name()
     print(fund_em_fund_name_df)
+
     fund_em_open_fund_daily_df = fund_em_open_fund_daily()
     print(fund_em_open_fund_daily_df)
     time.sleep(3)
-    fund_em_info_net_df = fund_em_open_fund_info(fund="000471", indicator="单位净值走势")
-    print(fund_em_info_net_df)
+
+    fund_em_open_fund_info_df = fund_em_open_fund_info(
+        fund="000212", indicator="单位净值走势"
+    )
+    print(fund_em_open_fund_info_df)
     time.sleep(3)
-    fund_em_info_net_acc_df = fund_em_open_fund_info(fund="710001", indicator="累计净值走势")
+
+    fund_em_info_net_acc_df = fund_em_open_fund_info(fund="000212", indicator="累计净值走势")
     print(fund_em_info_net_acc_df)
     time.sleep(3)
+
     fund_em_info_acc_return_df = fund_em_open_fund_info(
         fund="710001", indicator="累计收益率走势"
     )
     print(fund_em_info_acc_return_df)
     time.sleep(3)
+
     fund_em_info_rank_df = fund_em_open_fund_info(fund="710001", indicator="同类排名走势")
     print(fund_em_info_rank_df)
     time.sleep(3)
+
     fund_em_info_rank_per_df = fund_em_open_fund_info(
         fund="710001", indicator="同类排名百分比"
     )
     print(fund_em_info_rank_per_df)
     time.sleep(3)
+
     fund_em_info_cash_df = fund_em_open_fund_info(fund="161606", indicator="分红送配详情")
     print(fund_em_info_cash_df)
     time.sleep(3)
+
     fund_em_info_div_per_df = fund_em_open_fund_info(fund="161725", indicator="拆分详情")
     print(fund_em_info_div_per_df)
 
@@ -910,14 +951,16 @@ if __name__ == "__main__":
     fund_em_etf_fund_daily_df = fund_em_etf_fund_daily()
     print(fund_em_etf_fund_daily_df)
 
-    fund_em_etf_fund_info_df = fund_em_etf_fund_info(fund="163406")
+    fund_em_etf_fund_info_df = fund_em_etf_fund_info(
+        fund="511280", start_date="20000101", end_date="20500101"
+    )
     print(fund_em_etf_fund_info_df)
 
     fund_em_value_estimation_df = fund_em_value_estimation(symbol="混合型")
     print(fund_em_value_estimation_df)
 
-    fund_em_hk_fund_hist_df = fund_em_hk_fund_hist(code='1002200683', symbol="历史净值明细")
+    fund_em_hk_fund_hist_df = fund_em_hk_fund_hist(code="1002200683", symbol="历史净值明细")
     print(fund_em_hk_fund_hist_df)
 
-    fund_em_hk_fund_hist_df = fund_em_hk_fund_hist(code='1002200683', symbol="分红送配详情")
+    fund_em_hk_fund_hist_df = fund_em_hk_fund_hist(code="1002200683", symbol="分红送配详情")
     print(fund_em_hk_fund_hist_df)
