@@ -1,26 +1,26 @@
+#!/usr/bin/env python
 # -*- coding:utf-8 -*-
-# /usr/bin/env python
 """
-Date: 2021/1/16 20:04
-Desc: 东方财富网-数据中心-开放式基金排行
+Date: 2021/11/17 17:04
+Desc: 东方财富网-数据中心-开放基金排行
 http://fund.eastmoney.com/data/fundranking.html
 名词解释
 http://help.1234567.com.cn/list_236.html
 """
 import datetime
 
-import demjson
+from mssdk.utils import demjson
 import pandas as pd
 import requests
 
 
 def fund_em_open_fund_rank(symbol: str = "全部") -> pd.DataFrame:
     """
-    东方财富网-数据中心-开放式基金排行
+    东方财富网-数据中心-开放基金排行
     http://fund.eastmoney.com/data/fundranking.html
     :param symbol: choice of {"全部", "股票型", "混合型", "债券型", "指数型", "QDII", "LOF", "FOF"}
     :type symbol: str
-    :return: 开放式基金排行数据
+    :return: 开放基金排行
     :rtype: pandas.DataFrame
     """
     current_date = datetime.datetime.now().date().isoformat()
@@ -281,6 +281,7 @@ def fund_em_money_rank() -> pd.DataFrame:
 def fund_em_lcx_rank() -> pd.DataFrame:
     """
     东方财富网-数据中心-理财基金排行
+    # 该接口暂时没有数据
     http://fund.eastmoney.com/data/lcxfundranking.html#t;c0;r;sSYL_Z;ddesc;pn50;f;os1;
     :return: 理财基金排行
     :rtype: pandas.DataFrame
