@@ -1,9 +1,13 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Date: 2020/12/30 16:37
+Date: 2021/5/1 16:37
 Desc: 中国期货市场监控中心-指数
 http://index.cfmmc.com/index/views/index.html
+该数据由中国期货市场监控中心转移到中证商品指数有限责任公司进行管理
+中证商品指数有限责任公司：http://www.cscidx.com/index.html
+截止目前该网站还未更新指数上线
+# TODO 等待网站更新数据
 """
 from io import BytesIO
 
