@@ -1,10 +1,8 @@
 # -*- coding:utf-8 -*-
 # /usr/bin/env python
 """
-Author: Albert King
-date: 2020/01/02 17:37
-contact: jindaxiang@163.com
-desc: 获取交易法门-工具: https://www.jiaoyifamen.com/tools/
+Date: 2020/01/02 17:37
+Desc: 获取交易法门-工具: https://www.jiaoyifamen.com/tools/
 交易法门首页: https://www.jiaoyifamen.com/
 
 # 交易法门-工具-套利分析
@@ -1115,7 +1113,7 @@ def jyfm_tools_symbol_handbook(headers=""):
 
 if __name__ == "__main__":
     # 如果要测试函数, 请先在交易法门网站: https://www.jiaoyifamen.com/ 注册帐号密码, 在下面输入对应的帐号和密码后再运行 jyfm_login 函数!
-    headers = jyfm_login(account="link", password="loveloli888")
+    headers = jyfm_login(account="", password="")
 
     # 交易法门-工具-套利分析
     jyfm_tools_futures_spread_df = jyfm_tools_futures_spread(
