@@ -1,5 +1,5 @@
+#!/usr/bin/env python
 # -*- coding:utf-8 -*-
-# /usr/bin/env python
 """
 Date: 2020/9/10 18:02
 Desc: 东方财富网-数据中心-特色数据-商誉
@@ -9,7 +9,7 @@ Desc: 东方财富网-数据中心-特色数据-商誉
 东方财富网-数据中心-特色数据-商誉-个股商誉明细: http://data.eastmoney.com/sy/list.html
 东方财富网-数据中心-特色数据-商誉-行业商誉: http://data.eastmoney.com/sy/hylist.html
 """
-import demjson
+from mssdk.utils import demjson
 from py_mini_racer import py_mini_racer
 import pandas as pd
 import requests
